==> docx4j-openxml-objects-8.3.14-sources.jar: org/docx4j/math/CTMCPr.java <==
/*
 *  Copyright 2009-2012, Plutext Pty Ltd.
 *   
 *  This file is part of pptx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.docx4j.math;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_MCPr complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_MCPr">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="count" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_Integer255" minOccurs="0"/>
 *         &lt;element name="mcJc" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_XAlign" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_MCPr", propOrder = {
    "count",
    "mcJc"
})
public class CTMCPr
    implements Child
{

    protected CTInteger255 count;
    protected CTXAlign mcJc;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the count property.
     * 
     * @return
     *     possible object is
     *     {@link CTInteger255 }
     *     
     */
    public CTInteger255 getCount() {
        return count;
    }

    /**
     * Sets the value of the count property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTInteger255 }
     *     
     */
    public void setCount(CTInteger255 value) {
        this.count = value;
    }

    /**
     * Gets the value of the mcJc property.
     * 
     * @return
     *     possible object is
     *     {@link CTXAlign }
     *     
     */
    public CTXAlign getMcJc() {
        return mcJc;
    }

    /**
     * Sets the value of the mcJc property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTXAlign }
     *     
     */
    public void setMcJc(CTXAlign value) {
        this.mcJc = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-11.4.5-sources.jar: org/docx4j/math/CTMCPr.java <==
/*
 *  Copyright 2009-2012, Plutext Pty Ltd.
 *   
 *  This file is part of pptx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.docx4j.math;

import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_MCPr complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_MCPr">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="count" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_Integer255" minOccurs="0"/>
 *         &lt;element name="mcJc" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_XAlign" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_MCPr", propOrder = {
    "count",
    "mcJc"
})
public class CTMCPr
    implements Child
{

    protected CTInteger255 count;
    protected CTXAlign mcJc;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the count property.
     * 
     * @return
     *     possible object is
     *     {@link CTInteger255 }
     *     
     */
    public CTInteger255 getCount() {
        return count;
    }

    /**
     * Sets the value of the count property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTInteger255 }
     *     
     */
    public void setCount(CTInteger255 value) {
        this.count = value;
    }

    /**
     * Gets the value of the mcJc property.
     * 
     * @return
     *     possible object is
     *     {@link CTXAlign }
     *     
     */
    public CTXAlign getMcJc() {
        return mcJc;
    }

    /**
     * Sets the value of the mcJc property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTXAlign }
     *     
     */
    public void setMcJc(CTXAlign value) {
        this.mcJc = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
